@@ -4,7 +4,7 @@ from requests import HTTPError, RequestException
 import logging
 import os
 import shutil
-from working_dir import WorkingDir
+from pycomunefirenze.working_dir import WorkingDir
 from pathlib import Path
 import psycopg2
 import sys
